==> tine20-inventory_2019.12.5.tar.bz2: Inventory/js/Inventory-lang-ru-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Inventory **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Inventory'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-12-13 11:05+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Russian (http://www.transifex.com/tine20/tine20/language/ru/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: ru\nPlural-Forms: nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Inventory item, Inventory items"
: [
  "предметы из инвентаризации"
 ,"предметы из инвентаризации"
 ,"предметы из инвентаризации"
 ,"предметы из инвентаризации"

]
, "Inventory item list, Inventory item lists"
: [
  "лист инвентаризации"
 ,"листы инвентаризации"
 ,""
 ,"листы инвентаризации"

]
, "Name"
: "Название"

, "Status"
: "Состояние"

, "Inventory ID"
: "Инвентарный №"

, "Description"
: "Описание"

, "Location"
: "Расположение"

, "Invoice date"
: "Дата счёта"

, "Invoice"
: "Счёт"

, "Price"
: "Цена"

, "Cost Center"
: "Затраты"

, "Warranty"
: "Гарантия"

, "Item added"
: "Пункт добавлен"

, "Item removed"
: "пункт удалён"

, "Deprecate"
: ""

, "The active number must be less than or equal total number."
: "Этот номер должен быть меньше или равным общему."

, "General"
: "Общее"

, "ID"
: "№"

, "Enter description"
: "Введите описание"

, "Added"
: "Добавлен"

, "Removed"
: "Удалено"

, "Total number"
: "Общее число"

, "Available number"
: "Доступный номер"

, "Accounting"
: "Учёт"

, "Cost center"
: ""

, "Depreciate"
: "Не используется"

, "Default Inventory Item Container"
: "Контейнер по-умолчанию для инвентаризации"

, "The default container for new items"
: "Контейнер по-умолчанию для новых предметов"

, "Inventory Status Available"
: "Доступен статус инвенторизации"

, "Possible status."
: "Возможное состояние."

, "ordered"
: "заказан"

, "available"
: "доступен"

, "defect"
: "повреждён"

, "missing"
: "утерян"

, "removed"
: "списан"

, "unknown"
: "неизвестно"

, "Inventory CSV import"
: "Импорт файла CSV"

, "Import list (###CURRENTDATE###)"
: "Импорт списка (###CURRENTDATE###)"

, "Items imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: "Предметы импортированы ###CURRENTDATE### в ###CURRENTTIME### пользователем ###USERFULLNAME###"

, "All Inventory Items"
: "Все предметы из инвентаризации"

, "All existing Inventory Items"
: "Все существующие предметы из инвентаризации"

, "Inventory"
: "инвентарь"

, "Inventory item"
: "предметы из инвентаризации"

, "Inventory item list"
: "лист инвентаризации"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-inventory_2020.03.4.tar.bz2: Inventory/js/Inventory-lang-ru-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Inventory **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Inventory'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-12-13 11:05+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Russian (http://www.transifex.com/tine20/tine20/language/ru/)\nLanguage: ru\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Default Inventory Item Container"
: "Контейнер по-умолчанию для инвентаризации"

, "The default container for new items"
: "Контейнер по-умолчанию для новых предметов"

, "The active number must be less than or equal total number."
: "Этот номер должен быть меньше или равным общему."

, "General"
: "Общее"

, "ID"
: "№"

, "Name"
: "Название"

, "Description"
: "Описание"

, "Enter description"
: "Введите описание"

, "Location"
: "Расположение"

, "Added"
: "Добавлен"

, "Warranty"
: "Гарантия"

, "Removed"
: "Удалено"

, "Total number"
: "Общее число"

, "Available number"
: "Доступный номер"

, "Status"
: "Состояние"

, "Accounting"
: "Учёт"

, "Price"
: "Цена"

, "Cost center"
: ""

, "Invoice"
: "Счёт"

, "Invoice date"
: "Дата счёта"

, "Depreciate"
: "Не используется"

, "All Inventory Items"
: "Все предметы из инвентаризации"

, "All existing Inventory Items"
: "Все существующие предметы из инвентаризации"

, "Inventory"
: "инвентарь"

, "Inventory Status Available"
: "Доступен статус инвенторизации"

, "Possible status."
: "Возможное состояние."

, "ordered"
: "заказан"

, "available"
: "доступен"

, "defect"
: "повреждён"

, "missing"
: "утерян"

, "removed"
: "списан"

, "unknown"
: "неизвестно"

, "Inventory item, Inventory items"
: [
  "предметы из инвентаризации"
 ,"предметы из инвентаризации"
 ,"предметы из инвентаризации"
 ,"предметы из инвентаризации"

]
, "Inventory item list, Inventory item lists"
: [
  "лист инвентаризации"
 ,"листы инвентаризации"
 ,""
 ,"листы инвентаризации"

]
, "Inventory ID"
: "Инвентарный №"

, "Cost Center"
: "Затраты"

, "Item added"
: "Пункт добавлен"

, "Item removed"
: "пункт удалён"

, "Inventory CSV import"
: "Импорт файла CSV"

, "Import list (###CURRENTDATE###)"
: "Импорт списка (###CURRENTDATE###)"

, "Items imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: "Предметы импортированы ###CURRENTDATE### в ###CURRENTTIME### пользователем ###USERFULLNAME###"

, "Inventory item"
: "предметы из инвентаризации"

, "Inventory item list"
: "лист инвентаризации"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
